import { Component, OnInit, Input, Output, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { ProbeHost } from '@overflow/commons-typescript/model/probe';
import { Store, select } from '@ngrx/store';
import * as ProbeStore from '../store/entity/probe';
import { ProbeDetailContainerSelector } from '../store';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: 'of-probe-detail-container',
  templateUrl: './probe-detail-container.component.html',
})
export class ProbeDetailContainerComponent implements OnInit, OnChanges {

  @Input() probeHostID: number;
  @Output() discovery = new EventEmitter<number>();
  probeHost$: Observable<ProbeHost>;
  pending$: Observable<boolean>;
  error$: Observable<any>;

  constructor(
    private store: Store<any>,
    private route: ActivatedRoute,
  ) {
  }

  ngOnInit() {
    this.pending$ = this.store.pipe(select(ProbeDetailContainerSelector.selectPending));
    this.error$ = this.store.pipe(select(ProbeDetailContainerSelector.selectError));
    this.probeHost$ = this.store.pipe(select(ProbeDetailContainerSelector.selectOne(this.probeHostID)));
  }

  ngOnChanges(changes: SimpleChanges): void {
    this.store.dispatch(new ProbeStore.Read(this.probeHostID));
  }

  onModify(probeHost: ProbeHost) {
    this.store.dispatch(new ProbeStore.Modify(probeHost.probe));
  }

  onDiscovery(probeHostID: number) {
    this.discovery.emit(probeHostID);
  }
}
